package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````\"(```````!``````````$BS````
M`````````$``.``)`$``'P`>``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````<`````````!P``````````0`````````!````
M!0```````````````````````````````````!"?````````$)\`````````
M`"````````$````&````<*T```````!PK2```````'"M(```````F`0`````
M```P%0``````````(````````@````8```"8K0```````)BM(```````F*T@
M```````@`@```````"`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````8)<```````!@EP```````&"7````````!`$````````$`0````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````'"M````````<*T@``````!PK2``
M`````)`"````````D`(````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````%`````,```!'3E4`YGJ`WIGMPB2-?.9Y_"=`\L!5
M'0T$````$`````$```!'3E4```````,````"`````````&$```!B````````
M``````!'````!```````````````)0``````````````(P```!H`````````
M.`````@```!8`````````!0```!!````0@```#H```!1````7@````8````Y
M```````````````#````5````#P``````````````$0```!,````2```````
M````````80````P`````````+``````````S`````````$D```!3````0```
M`#0`````````70```%<`````````$P````<``````````````$L````@````
M+@```"0`````````````````````````%@`````````````````````````!
M````'P````H````]````7P```#L``````````````%4```!&````)@```%``
M``!#````,````"T`````````/@```````````````````%8```!%````````
M`"<```!-````+P````L````R`````@``````````````````````````````
M`````````````````````````````````````%D`````````````````````
M``````````````````````````````!@```````````````5````````````
M````````7````!(````7````$0````````!:````4@```"(`````````/P``
M````````````(0```````````````````"H````;````````````````````
M*0`````````8```````````````V`````````#4````)````6P```#<````Q
M````*``````````````````````````/````*P`````````%`````````!D`
M```<````'0`````````>```````````````0````#0``````````````````
M`$H```````````````````!.``````````X`````````````````````````
M3P```````````````````!$````_````!`````@````@'!``!4`$AB@"0`20
MA@"$@@D`($D@!`BXHA%-N@`&"@`````_````0@```$4```!&````3@```$\`
M``!1````50```%8```!8````60```%P```!>````8```````````````;L7?
M'\[>1RUK?YI\+L6;MB#_Y`[59-1\V7%8'.)'Q@%"^M>'K$OCP/+;TQVZXY)\
MPN4_+/JA;&"S`8MO:PE#UF:OS&;%N9Q`0D75[,2)!9"(!W#3.?*+'`T4XI[:
MS>.>,V+;[16,)<P,.I<+5J2;EJ?=HVM^J9R;T67.;>"G`@IK&IY0"HH05Z/@
M^TD```````````````````````````````#A````$@``````````````````
M``````"G`0``$@````````````````````````#S`0``$@``````````````
M``````````#1`0``$@`````````````````````````!````(```````````
M``````````````#Z`0``$@````````````````````````"&`@``$@``````
M```````````````````/`@``$@````````````````````````!%`0``$@``
M``````````````````````!N`@``$@````````````````````````!F`@``
M$@````````````````````````!T````$@````````````````````````!9
M`P``$@````````````````````````#<````$@``````````````````````
M```R`@``$@`````````````````````````D`@``$@``````````````````
M``````#B`0``$@````````````````````````!_`@``$@``````````````
M``````````"/`@``$@`````````````````````````W`0``$@``````````
M```````````````%`0``$@````````````````````````!S`0``$@``````
M``````````````````"-`0``$@````````````````````````#9`0``$@``
M``````````````````````#O`@``$@````````````````````````!@`0``
M$@`````````````````````````(`@``$@````````````````````````";
M`0``$@````````````````````````#3`@``$@``````````````````````
M``#,`@``$@`````````````````````````3`0``$@``````````````````
M```````=````(`````````````````````````!&`@``$@``````````````
M``````````!4````$@````````````````````````"X`0``$@``````````
M``````````````!L`0``$@````````````````````````"#````$@``````
M``````````````````"/````$@`````````````````````````L`0``$@``
M``````````````````````#R````$@````````````````````````!&````
M$@````````````````````````#F````$@````````````````````````!-
M`@``$@````````````````````````!5`0``$@``````````````````````
M``#`````$@```````````````````````````@``$@``````````````````
M``````"@`0``$@````````````````````````"]`@``$@``````````````
M``````````"6`@``$@````````````````````````!C````$@``````````
M``````````````#%`@``$@`````````````````````````=`@``$@``````
M``````````````````"D````$@`````````````````````````C`0``$@``
M``````````````````````!;`@``$@````````````````````````#,`0``
M$@````````````````````````"3`0``$@`````````````````````````X
M`@``$@`````````````````````````L````(```````````````````````
M```6`@``$@`````````````````````````K`@``$@``````````````````
M``````"O`@``$@````````````````````````!B`P``$@`/`#`]````````
M=P````````".`P``$@`/`,`R````````V0<```````#@`@``$@`/`+`@````
M````-`(````````V`P``$@`/```L````````!0`````````B!```$@`/`!`L
M`````````@(```````!8!```$@`/`*`Z````````C0(````````.!```$``<
M``BR(`````````````````!U`P``$@`/`"`N````````*@````````";`P``
M$@`/`"!4````````D@$```````"S`P``$0`1`,A8````````!`````````!^
M`0``$0`6`("M(```````$P````````#R`P``$``<`*#"(```````````````
M```:!```$@`/`+`J````````,``````````O!```$@`/`.`Q````````W```
M``````!!!```$@`/`#`Q````````=`````````"F`P``$``:`-"Q(```````
M``````````""`P``$@`/`%`N````````[`````````#E`@``$0`<`$BR(```
M````"`````````!N`P``$``;``BR(`````````````````#F`@``(0`<`$BR
M(```````"`````````#H`P``$0`:`.BQ(```````"`````````!X`@``$0`<
M`&"R(```````"``````````F`P``$@`/`(Y8````````!`````````#8`P``
M$@`/``Y8````````9P````````"L`P``$@`/`/`B````````*P````````!/
M!```$@`/`,!3````````5`````````"H`P``(``:`-"Q(```````````````
M``#1````$0`<`""R(```````!`````````#G`@``(0`<`$BR(```````"```
M``````!'`P``$@`/`+`Q````````)`````````"@`@``(@``````````````
M``````````#"`P``$@`/`#`K````````P0`````````$!```$@`/`,!5````
M````,P(```````"S````$0`<`$"R(````````0````````#W`P``$@`/`$`O
M````````XP$`````````7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%]?
M9VUO;E]S=&%R=%]?`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S
M>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?
M8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E
M<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,
M7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N
M;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!0
M97)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?
M<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y
M7W=R87``8VQO<V4`;'-E96LV-`!R96%D`&]P96XV-`!?7V5R<FYO7VQO8V%T
M:6]N`'!T:')E861?9V5T<W!E8VEF:6,`97AI=`!S=')N8VUP`&-L;W-E9&ER
M`%]?<W1A8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`;65M8VAR
M`&=E='!I9`!S=')D=7``<W1R=&]K`'-T<FQE;@!S=')S='(`<FUD:7(`7U]F
M<')I;G1F7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P
M96YD:7(`7U]X<W1A=#8T`'-T9&5R<@!G971U:60`<F5A9&QI;FL`<W1R8VAR
M`')E861D:7(V-`!?7V-X85]F:6YA;&EZ90!?7W-P<FEN=&9?8VAK`&UE;6UO
M=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`
M7U]R96=I<W1E<E]A=&9O<FL`;&EB<&5R;"YS;P!L:6)P=&AR96%D+G-O+C``
M;&EB8RYS;RXV`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C`&=E
M=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]E9&%T80!P
M87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`'-H85]U<&1A
M=&4`7U]D871A7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X
M96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`%]E;F0`<&%R7VEN
M:71?96YV`'-H85]F:6YA;`!?7V)S<U]S=&%R=`!X<U]I;FET`'!A<E]F:6YD
M<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`'-H85]I;FET
M`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C(N-0!'3$E"0U\R+C,N
M-`!'3$E"0U\R+C$T`$=,24)#7S(N,RXR`$=,24)#7S(N-``O=7-R+VQI8B]P
M97)L-2\U+C(V+C$O>#@V7S8T+6QI;G5X+71H<F5A9"UM=6QT:2]#3U)%````
M`@`#``(``@`!``(``@`"``$``@`"``$``@`!``(``@`$``(``@`!``$``0`#
M``(`!0`!``(``P`"``(``0`!``8``0`#``(``0`!``$``0`!``$`!P`!``$`
M`@`#``(``@`!``(``@`!``$``@`"``,`!P`!``(``@`'``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`"``$``@`!``(``0`!``$``0`!``$`
M`@`!``(``0`!``$``0`!``$`#`,``!`````@````=1II"0```P!N!```````
M``$`!0`<`P``$`````````!T&6D)```'`'H$```0````E)&6!@``!@"&!```
M$````'(9:0D```4`D00``!`````4:6D-```$`)T$```0````=1II"0```@!N
M!````````'"M(```````"`````````#P(P```````'BM(```````"```````
M``"P(P```````-BQ(```````"`````````#8L2```````.BQ(```````"```
M``````#@6P```````/"Q(```````"```````````6````````/BQ(```````
M"`````````"`6`````````"R(```````"`````````"@6````````+BO(```
M````!@````4``````````````,"O(```````!@````D``````````````,BO
M(```````!@```!T``````````````-"O(```````!@```"``````````````
M`-BO(```````!@```"@``````````````."O(```````!@```#(`````````
M`````.BO(```````!@```#L``````````````/"O(```````!@```%T`````
M`````````("M(```````!0```$D``````````````""R(```````!0```%H`
M`````````````$"R(```````!0```&```````````````$BR(```````!0``
M`%```````````````&"R(```````!0```%0``````````````!BP(```````
M!P````$``````````````""P(```````!P````(``````````````"BP(```
M````!P````,``````````````#"P(```````!P````0``````````````#BP
M(```````!P````8``````````````$"P(```````!P````<`````````````
M`$BP(```````!P````@``````````````%"P(```````!P````H`````````
M`````%BP(```````!P````L``````````````&"P(```````!P````P`````
M`````````&BP(```````!P````T``````````````'"P(```````!P````X`
M`````````````'BP(```````!P````\``````````````("P(```````!P``
M`!```````````````(BP(```````!P```!$``````````````)"P(```````
M!P```!(``````````````)BP(```````!P```!,``````````````*"P(```
M````!P```!0``````````````*BP(```````!P```!4``````````````+"P
M(```````!P```!8``````````````+BP(```````!P```!<`````````````
M`,"P(```````!P```!@``````````````,BP(```````!P```!D`````````
M`````-"P(```````!P```!H``````````````-BP(```````!P```!L`````
M`````````."P(```````!P```!P``````````````.BP(```````!P```!X`
M`````````````/"P(```````!P```!\``````````````/BP(```````!P``
M`"$```````````````"Q(```````!P```"(```````````````BQ(```````
M!P```",``````````````!"Q(```````!P```"0``````````````!BQ(```
M````!P```"4``````````````""Q(```````!P```"8``````````````"BQ
M(```````!P```"<``````````````#"Q(```````!P```"D`````````````
M`#BQ(```````!P```"H``````````````$"Q(```````!P```"L`````````
M`````$BQ(```````!P```"P``````````````%"Q(```````!P```"T`````
M`````````%BQ(```````!P```"X``````````````&"Q(```````!P```"\`
M`````````````&BQ(```````!P```#```````````````'"Q(```````!P``
M`#$``````````````'BQ(```````!P```#,``````````````("Q(```````
M!P```#0``````````````(BQ(```````!P```#4``````````````)"Q(```
M````!P```#8``````````````)BQ(```````!P```#<``````````````*"Q
M(```````!P```#@``````````````*BQ(```````!P```#D`````````````
M`+"Q(```````!P```#H``````````````+BQ(```````!P```#P`````````
M`````,"Q(```````!P```#T``````````````,BQ(```````!P```#X`````
M`````````$B#[`A(BP6]DB``2(7`=`+_T$B#Q`C#`/\UXI(@`/\EY)(@``\?
M0`#_)>*2(`!H`````.G@_____R7:DB``:`$```#IT/____\ETI(@`&@"````
MZ<#_____)<J2(`!H`P```.FP_____R7"DB``:`0```#IH/____\ENI(@`&@%
M````Z9#_____);*2(`!H!@```.F`_____R6JDB``:`<```#I</____\EHI(@
M`&@(````Z6#_____)9J2(`!H"0```.E0_____R62DB``:`H```#I0/____\E
MBI(@`&@+````Z3#_____)8*2(`!H#````.D@_____R5ZDB``:`T```#I$/__
M__\E<I(@`&@.````Z0#_____)6J2(`!H#P```.GP_O___R5BDB``:!````#I
MX/[___\E6I(@`&@1````Z=#^____)5*2(`!H$@```.G`_O___R5*DB``:!,`
M``#IL/[___\E0I(@`&@4````Z:#^____)3J2(`!H%0```.F0_O___R4RDB``
M:!8```#I@/[___\E*I(@`&@7````Z7#^____)2*2(`!H&````.E@_O___R4:
MDB``:!D```#I4/[___\E$I(@`&@:````Z4#^____)0J2(`!H&P```.DP_O__
M_R4"DB``:!P```#I(/[___\E^I$@`&@=````Z1#^____)?*1(`!H'@```.D`
M_O___R7JD2``:!\```#I\/W___\EXI$@`&@@````Z>#]____)=J1(`!H(0``
M`.G0_?___R72D2``:"(```#IP/W___\ERI$@`&@C````Z;#]____)<*1(`!H
M)````.F@_?___R6ZD2``:"4```#ID/W___\ELI$@`&@F````Z8#]____):J1
M(`!H)P```.EP_?___R6BD2``:"@```#I8/W___\EFI$@`&@I````Z5#]____
M)9*1(`!H*@```.E`_?___R6*D2``:"L```#I,/W___\E@I$@`&@L````Z2#]
M____)7J1(`!H+0```.D0_?___R5RD2``:"X```#I`/W___\E:I$@`&@O````
MZ?#\____)6*1(`!H,````.G@_/___R5:D2``:#$```#IT/S___\E4I$@`&@R
M````Z<#\____)4J1(`!H,P```.FP_/___R5"D2``:#0```#IH/S___\E.I$@
M`&@U````Z9#\____)3*1(`!H-@```.F`_/___R5*CR``9I```````````%53
M2(/L.(E\)!Q(B70D$$B-?"0<2(E4)`A(C70D$$B-5"0(9$B+!"4H````2(E$
M)"@QP.@8_O__2(LUZ8X@`$B+/>J.(`!(B?+HL#<``(`].Y$@``!U+^A4_?__
M2(7`2(D%@J$@``^$O@$``$B)Q^B<_/__BSWVD"``Z.']___&@-$(````BSWD
MD"``Z,_]__^`B*H$```"BSW2D"``Z+W]__^`B*H$```!BT0D'(UX!(U8`TBX
M_________Q](8_](.<</AR(!``!(P><#Z!W]__](BWPD$$B-#0@Y``!$BT0D
M'$B)!?6@(`!(BQ=(B4@(2(T-\3@``$&#^`%(B4@82(D02(L5+9`@`$B)4!`/
MCLT```!(@\<(08/``[X$````9@\?1```2(L/2&/6@\8!2(/'"$0YQDB)#-!U
MZDAC]DC!Y@-(BSV<H"``2,<$,`````!(C375"```13'`B=I(B<'H>/W__X7`
MB<-T9$B+/7.@(`!(C6PD).@1_/__2(T]-C<``#'`2(GNZ,`!``!(A<!T*DB+
M/4R@(`#HC_O__^@*_?__B=A(BUPD*&1(,QPE*````'5M2(/$.%M=PTB+/1*@
M(`!(A?]T-NBP&@``Z\-(BST/H"``Z)+]__^)P^N,OB````#I6?___TB--=V*
M(`!(C3UT-@``,<#HC_S__TB-/6DV``!(B>[H0`$``$B%P$B)QTB)!;N?(``/
MA'+____KIN@V^___OP$```#H7/W__V8N#Q^$``````!FD#'M28G17DB)XDB#
MY/!05$R-!8@U``!(C0T!-0``2(T]G/W___\5KHP@`/0/'T0``$B-/<F.(`!5
M2(T%P8X@`$@Y^$B)Y7092(L%>HP@`$B%P'0-7?_@9BX/'X0``````%W#9F8N
M#Q^$```````/'P!(C3V)CB``2(TU@HX@`%5(*?Y(B>5(P?X#2(GP2,'H/T@!
MQDC1_G082(L%68P@`$B%P'0,7?_@9@\?A```````7<-F9BX/'X0```````\?
M`(`]L8X@``!U+TB#/2^,(```54B)Y70,2(L]"HX@`.C-_/__Z$C____&!8F.
M(``!7<,/'X``````\\-F#Q]$``!52(GE7>EF____9@\?1```05=!5D%50515
M4TB#[`A(A?\/A+$```!,BSTJCB``387_#X2A````#[8'A,!T!#P]=5Y%,>1)
MBQ](A=MT.4F)]4F)_DUCY$R)_0\?@`````!,B>),B?9(B=_H`OG__X7`=0="
M@#PC/71'2(/%"$B+70!(A=MUVDB#Q`A(B=A;74%<05U!7D%?PP\?A```````
M28G\28/$`4$/M@0DA,!T!#P]=>]!*?SKC`\?@`````!,*?U*C5PC`4C!_0-!
MB6T`Z[1F#Q]$```QV^NJ#Q]``%532(G]2(/L&&1(BP0E*````$B)1"0(,<!(
MC5PD!&:0,<!(B=Y(B>_H`____TB%P'0V2&-4)`1(BP4ZC2``2(T$T$B+4`A(
MA=)(B1!TTF:02(/`"$B+4`A(A=)(B1!U\.N^9@\?1```2(M$)`AD2#,$)2@`
M``!U!TB#Q!A;7</HO/C__V9F+@\?A```````D$%7059!54%455-(B?-(B?U(
M@^PH9$B+!"4H````2(E$)!@QP#'`@#X]#Y3`2`'#2(G?Z&GX__](C70D%$F)
MQ$B)[S'`Z%?^__](A<`/A`X!``!(B<=)B<7H0_C__TPYX`^#X@```$QC="04
M2<'F`P^V10"$P`^$K0$``#P]#X2E`0``2(GHZPT/'X0``````(#Z/70+2(/`
M`0^V$(32=?!(*>A(F$P#-3R,(`!*C7P@`N@*^?__2(7`28D&#X1[`0``2&-4
M)!1(BP4:C"``2(U-`4B+%-`/MD4`/#V(`G0FA,!U$.L@9BX/'X0``````#P]
M=!)(@\$!#[9!_TB#P@&$P(@"=>K&`CTQP`\?1```#[8,`XA,`@%(@\`!A,EU
M\#'`2(MT)!AD2#,T)2@````/A1$!``!(@\0H6UU!7$%=05Y!7\,/'P!(@\,!
M#[9#_TF#Q0&$P$&(1?]U[.O"9I!,BSV!BR``28,_``^$OP```$R)^#'2ZPL/
M'X0``````$2)ZDB#P`A$C6H!2(,X`'7OC7(#2&/V2,'F`XL%?YL@`(7`=5M(
MB??'!6Z;(``!````Z`GX__](A<`/A'T```!-8\5,B?Y(B<=.C33%`````$R)
M1"0(3(GRZ)+X__],BT0D"$B)P4B)!?N*(`!*QT3!"`````!$B6PD%.EO_O__
M3(G_Z$CX__](A<!(B<%(B073BB``="9-8\5.C33%`````.O)#Q]``#'`Z7;^
M__^0OA````!%,>WI7O___[C_____Z=O^___H9/;__P\?0`!!5T%6055!5%53
M2('LN````&1(BP0E*````$B)A"2H````,<!(A?]T"(`_`$F)_G4O2(N$)*@`
M``!D2#,$)2@````/A2P!``!(@<2X````6UU!7$%=05Y!7\-F#Q]$``#HF_7_
M_TB%P$B)PW3$2(U$)!!(C2VD,```3(TEG#```$R-/9@P``!(B00D2(G?Z)WW
M__](A<`/A+P```!,C4@3N0(```!(B>],B<[SI@^7P!P`A,!TU;D#````3(G.
M3(GG\Z8/E\`<`(3`=+],B?=,B4PD".AW]?__3(M,)`A)B<5,B<_H9_7__T&-
M?`4"2&/_Z'KV__],BTPD"$F)Q4B)QTV)\$R)^4C'PO____^^`0```#'`Z,;W
M__](BQ0DOP$```!,B>[HQ?3__X/X_TR)[W00BT0D*"4`\```/0!```!T*NA8
M]/__3(GOZ##T___I-O___P\?`$B)W^AP]?__3(GWZ-CT___IQ/[__^B._O__
MZ]3HY_3__P\?@`````!32(G^2(G[OP$```!(@>R@````2(GB9$B+!"4H````
M2(F$))@````QP.C2]O__A<!U/HM4)!B!X@#P``"!^@!```!T-('Z`*```'0L
M2(N,))@```!D2#,,)2@```!U,$B!Q*````!;PP\?A```````,<#KV`\?0`"^
M`@```$B)W^@[]O__A<`/E,`/ML#KO>A,]/__9F8N#Q^$``````"0059!54F)
M]D%454F)_%-(C3WP+@``NO\/``!(@>P0$```2(GC2(G>9$B+!"4H````2(F$
M)`@0```QP.AQ\___A<`/CHD```"-4/]$BRW_AR``2&/J@#PL`'162&/H2(GJ
MOB\```!(B=_H<_3__TB%P'1&1(GOZ,;T__](B>E(B=I,B>9(B<?HM?7__TB+
MA"0($```9$@S!"4H````=3M(@<00$```6UU!7$%=05[#9I"%TG6I#Q]``$2)
M[^B`]/__3(GR3(GF2(G'Z++S___KNT2++7F'(`#KW^AB\___9I!(@^P(BSUF
MAR``Z%'T__](BQ7ZA"``2(T-^R\``$B--1`N``!(B<=(@\0(Z7#T__](@^P(
MBSTVAR``Z"'T__](B<?HN?___XL](X<@`.@.]/__3(T%:R\``$B-%9`/``!(
MC37I+0``13')2(G'2(/$"$R)P>EW]/__#Q^``````%532('L*"```&1(BP0E
M*````$B)A"08(```,<!(B>-(C:PD$!```.@T\O__3(T-?2T``$B-#:LM``!!
MB<"Z`1```+X!````2(G?,<#H#_7__[H`$```2(GN2(G?Z._Q__^%P'A3C7@!
M2(G#2&/_Z'WS__](A<!(B<%T&$ACVTB)[DB)QTB)VN@T\___2(G!Q@08`$B+
ME"08(```9$@S%"4H````2(G(=1-(@<0H(```6UW##Q]$```QR>O7Z!_R__]F
M9BX/'X0```````\?0`#I*____V9F+@\?A```````05=!5D%5051)B?154TB)
M^TB-/?HL``!(@>RX$```9$B+!"4H````2(F$)*@0```QP$B-="0,Z+7W__^^
M+P```$B)WTB)Q>C5\?__2(7`=$!(C3W#+```2(G>,<#H[_C__TB)V$B+C"2H
M$```9$@S#"4H````#X6"`0``2('$N!```%M=05Q!74%>05_##Q\`2(G?Z%CQ
M__](C36(+```3(GG08G%Z$;S__](A<!)B<=TGD&#Q0%!@#\`3(VD)*````!,
MC70D$`^$R0````\?`$B%[7033(G^2(GOZ.#Q__^%P`^$B@```$R)_^@`\?__
MB<)(F$&`?`?_+W47#Q]``(/J`4ACPD&`?`?_+T'&!`<`=.U$`>J!^O\/```/
MCR[___](@^P(2(T-\BP``$R-#?4K``!338GXN@`0``"^`0```$R)YS'`Z#3S
M__],B?),B>:_`0```.@T\/__A<!:6740BT0D*"4`\```/0"```!T7DB--:XK
M```Q_^AP\O__2(7`28G'#X3$_O__08`_``^%.O___TB%[70=2(T]&RL``+D"
M````2(GN\Z8/E\`<`(3`=+T/'P!,C3W^*@``N@$```#I2O___P\?@`````"^
M`0```$R)Y^@#\O__A<!UD4B-/3(K``!,B>;H8/?__TR)Y^AH\O__Z6?^___H
M_N___V9F+@\?A```````#Q\`#[872(GXA-)T'F8/'T0``$B#QP&`^B\/MA=(
M#T3'A-)U[O/##Q]``//#9@\?1```2(7_#X3/````55-(@^P(#[8O0(3M="E(
MB?OHD>___TB-5`/_2#G3<A#K.P\?1```2(/J`4@YTW0W@#HO=/+K'4B#Q`A(
MC3TR*@``6UWISO'__V8/'T0``(`Z+W0X2(/J`4@YTW+R2#G3=2H/'T0``$"`
M_2]TRDB#Q`A(C3UH*@``6UWIF/'__P\?A```````@#HO=0E(@^H!2#G3<O)(
M*=I(C4("2#T`$```=SM(C3U\@R``2(/"`;D`$```2(G>Z&OP__](C05D@R``
M2(/$"%M=PP\?1```2(T]GBD``.D\\?__#Q]``#'`Z^`/'T``4TB-/?,I``!(
M@^Q`9$B+!"4H````2(E$)#@QP`^W!5TK``!(C5PD#/,/;P4P*P``#RE$)!!F
MB40D,#'`\P]O!2PK```/*40D(.A"]?__2(T]KRD``#'`Z#3U__](C3VI*0``
M,<#H)O7__TB-/:0I```QP.@8]?__2(T]G2D``#'`Z`KU__](C3V?*0``,<#H
M_/3__TB-/48I```QP.CN]/__2(T]CRD``#'`Z.#T__](C3V+*0``,<#HTO3_
M_TB-/8<I```QP.C$]/__2(T]%RD``#'`Z+;T__](C3UU*0``,<!(B=[HU?/_
M_TB%P'012(T]2RD``$B)QC'`Z!_U__](C3U?*0``,<!(B=[HKO/__TB%P'01
M2(T]6RD``$B)QC'`Z/CT__](C3U5*0``,<!(B=[HA_/__TB%P'1"2(T]G"@`
M`$B)QC'`Z-'T__](C35:*0``2(T]OR@``#'`Z+ST__](BT0D.&1(,P0E*```
M`'5J2(/$0%O#9@\?1```2(T]#2D``#'`2(G>Z"_S__](A<!U,DB-="0A2(T]
M`RD``+D*````\Z8/E\`<`(3`=9U(C70D*TB-/7HH``#H7?3__^N*#Q\`2(T]
M:2@``$B)QC'`Z$?T___I<?___^CM[/__9F8N#Q^$``````!FD$B#[!AD2(L$
M)2@```!(B40D"#'`BP66@"``@_C_=!E(BWPD"&1(,SPE*````'5`2(/$&,,/
M'T``2(UT)`1(C3T$*```,<#HA?+__TB)PC'`2(72=!(/MA*`^C`/E<$QP(32
M#Y7`(<B)!4.`(`#KL.AL[/__9F8N#Q^$``````"02(/L".AG[/__B<?H$.S_
M_TB%P'0+2(L`2(/$",,/'P`QP.OT9F8N#Q^$``````"005152(G]4TB-/00H
M``!(@^P09$B+!"4H````2(E$)`@QP$B-="0$Z/3Q__](A<!(B>YT?(`X`$B)
MPW1T2(G'Z%SN__](A<!U=4B)[^C/Z___2(G?28G$Z,3K__])C7P$`NC:[/__
M2(/L"$R-#>8F``!(C0W7)P``4TC'PO____](B<=)B<1)B>B^`0```#'`Z!ON
M__](C3UV)P``3(GF,<#HVO+__UA:ZQ1F#Q]$``!(C3U;)P``,<#HPO+__TB+
M1"0(9$@S!"4H````=0E(@\006UU!7,/H5.O__P\?0`!!5T%6055!5$F)_553
M2(T]328``$B![(B!``!D2(L$)2@```!(B80D>($``#'`2(T%&2<``$R-9"0<
M2,=$)#``````2,>$)(@`````````2,=$)%``````2(E$)"!(C06I)0``3(GF
M2(E$)"A(C06&)@``2(E$)&!(C05S)@``2(E$)&A(C07()@``2(E$)'!(C05X
M)@``2(E$)'A(C06X)@``2(F$)(````!(C060)@``2(E$)$!(C06A)@``2(E$
M)$@QP.AV\/__2(7`=`F`.``/A6@"```QP.@1_O__2(7`2(G##X2E`@``2(G?
MZ$WJ__](C7P``>ACZ___@#L`28G&=#5,C3U<)@``3(GUD$0/M@-(B>\QP$R)
M^4C'PO____^^`0```$B#PP%(@\4"Z)OL__^`.P!UUDB-7"1@2(T]LR4``.L8
M#Q^$``````!(@\,(2(L[2(7_#X2(`0``,<!,B>;HUN___TB%P$B)Q73>@#@`
M=-E(B<?H\?3__X7`=,U(B>_H)>S__TB%P$F)P`^$40$``&8/'X0``````$R)
MPHL*2(/"!(V!__[^_O?1(<@E@("`@'3IB<'!Z1"I@(````]$P4B-2@)(#T31
MB<$`P4R)\4B#V@-,*<*+,4B#P02-AO_^_O[WUB'P)8"`@(!TZ8G&3(E$)`C!
M[A"I@(````]$QDB-<0)(#T3.B<9``,9(@]D#3"GQC9P*!`0``$ACVTB)W^@T
MZO__28G'2(T%0"4``$%63(T-.B0``$B-#2<E``!(Q\+_____4$R+1"08O@$`
M``!,B?\QP.ANZ___3(G_OL`!``#H0>C__X/X_U]!6'42Z`3H__]$BPA!@_D1
M#X6Y!```2(V4))````!,B?Z_`0```.C2ZO__A<")Q747BX0DJ````"4`\```
M/0!````/A$4!``!)BTT`2(L]VGP@`$B-%8LE``!-B?B^`0```#'`,=OHPNK_
M_^E]````#Q]$```Q[68/'T0``$ACQ4B+7,0@2(7;=#N`.P!T-DB)WX/%`>AC
M\___A<!TWTB)W^B7ZO__2(7`28G`#X5[_O__2&/%2(M<Q"!(A=MURV8/'T0`
M`$4QP.E@_O__2(G'2(E$)`CHT_O__TB+1"0(2(G'Z%;J__](B<,/'P!(BXPD
M>($``&1(,PPE*````$B)V`^%6@0``$B!Q(B!``!;74%<05U!7D%?PP\?0`!(
MC3VK(P``,>U(A?]T)F:0,<!,B>:#Q0'HD^W__TB%P'0%@#@`=2E(8\5(BWS$
M0$B%_W7<OPT```!(C1UW(P``Z(OH__])B<;I*/W__P\?`$B)Q^C(Z?__2(7`
M2(G##X7W_/__Z\%F+@\?A```````1(NT)*P```#H4^?__T$YQ@^%I?[__XN$
M)*@````E_P$``#W``0``#X6._O__2(G?Z"OH__](C3T!(P``2(G#3(GF,<#H
M]^S__TB%P`^$;@$``$B)Q^A6Z?__28M]`$B)QNCJ]/__2(7`28G$#X1.`0``
M3(GGZ,;F__^#^`-^04ACT$B-/?(B``"Y!0```$F-=!3\\Z8/E\*`V@"$TG4A
M@_@$#X18`@``@^@$2)A!@'P$_R\/A$<"```/'X``````,<#HJ?G__X7`=14Q
M]DR)Y^@KZ/__A<!!B<0/A?````!(C35)(@``2(T]RB$``$R-);\B```QP$R-
M+7LA``#HG>W__^C(Y?__051,C0UH(0``4$B-#7LB``!(Q\+_____38GXO@$`
M``!(B=\QP.B>Z/__6%KK2V8N#Q^$``````#H.^7__X,X$75)Z('E__^#Q0%(
M@^P(2(T-12(``$%454V)Z5!-B?A(Q\+_____O@$```!(B=\QP.A3Z/__2(/$
M(+[``0``2(G?Z"+E__^#^/]TK4R)_^C5Y/__2(T]OR```$B)WC'`Z/3L__](
MB=_H;/G__^FG_?__#Q^``````$V+90#IJ?[__P\?@`````!(C:PD<`$``+H"
M````2,?&[O___XG'Z*7G__^Z!@```$B)[D2)Y^@%YO__@+PD<`$```!U#H"\
M)'$!``!##X17`0``,=(Q]D2)Y^AQY___,<#HVAH``$F)Q>L2#Q]$``")PDB)
M[DR)[^@C&P``N@"```!(B>Y$B>?HL^7__X7`?]],C;0D(`$``$2)YTR-)04A
M``#H2.7__TR)[DR)]TR-K"1H`0``Z(4<``!(C80D0`$``$B)1"0(2(G%#Q]$
M``!%#[8&2(GO,<!,B>%(Q\+_____O@$```!(@\4"28/&`>@;Y___23GM==9(
MC07S(```QH0D:`$```!0_W0D$$B-#;`@``!,C0V='P``O@$```!-B?A(Q\+_
M____2(G?,<#HV^;__UE>Z9?^__\/'T``38MM"$V%[0^$L_W__TR)[^@KY/__
M2(/X`P^&H?W__TF-=`7\2(T]52```+D%````\Z8/E\`<`(3`30]$Y>E^_?__
M28M-`$B+/5-X(`!(C17$(```38GXO@$````QP#';Z#OF___I]OO__X"\)'(!
M``!!#X6;_O__@+PD<P$``$,/A8W^__^`O"1T`0``2`^%?_[__X"\)'4!``!%
M#X5Q_O__N@(```!(Q\;&____1(GGZ-KE__^Z*0```$B)[D2)Y^@ZY/__2(T%
MYQ\``%!5Z?K^___H=^/__P\?@`````!!5%532(/L$(L]<G<@`&1(BP0E*```
M`$B)1"0(,<#H3>3__XL]5W<@`$B)P^@_Y/__#[:3N````$B-7"0$2(T]>!X`
M`$B)WHB0N0```#'`Z`SI__](A<!T"8`X,0^$K@$``#'`Z#?T__^+/1%W(`#H
M_./__TB--5@?``"Y`P```+H!````2(G'Z+/C__](A<!(B<5T-4B+0!"+/>%V
M(`!,BR#HR>/__TB-%2<?``!(B<=,B>;H]^+__TB+11!(BRCV10Y`#X6&`0``
MBSVP=B``Z)OC__](C37^'@``N0,```"Z`0```$B)Q^A2X___2(7`2(G%=#U(
MC3V-'0``,<!(B=[H6>C__TB%P$F)Q`^$#0$``$B+11"+/6-V(`!(BRCH2^/_
M_TR)XDB)QTB)[NA]XO__BSU'=B``Z#+C__](C367'@``N@$```!(B<?H/N/_
M_XL]*'8@`$B)Q>@0X___2(T5BAX``$B)[DB)Q^@^XO__BST(=B``Z//B__](
MC3W]'```QH"Y`````$B)WC'`Z,OG__](A<!(B<-(B05&AB``=#R^P`$``$B)
MW^@?X?__C5`!@_H!=@F#^!$/A:D```!(BT0D"&1(,P0E*`````^%L@```$B#
MQ!!;74%<PY!(BST)AB``Z#3V__](A<!(B<-(B07OA2``=:E(C3W.'@``,<#H
ME^+__P\?@`````"`>`$`#X1/_O__Z4/^__^02(L%R84@`(L]4W4@`$R+($B+
M11!(BRCH-.+__TR)YDB)[^CI[/__Z>?^__\/'T``BSTJ=2``Z!7B__](B>Y(
MB<?H:N+__^E?_O__B<%(BP5\A2``2(T]?1X``$B)VDB+,#'`Z!CB___HX^#_
M_P\?`%532(G]2(/L".@2\?__#[802(G#A-)T&@\?A```````2(/``8#Z+P^V
M$$@/1-B$TG7N,<#HQ_/__TB%[70DA<!T((!]``!T&DB-/;<<``"Y!````$B)
MWO.F#Y?`'`"$P'0'2(/$"%M=PTB#Q`A(B>];7>D)ZO__9@\?A```````05=!
M5DR-3SA!54%413'`55-(@>R8`@``9$B+!"4H````2(F$)(@"```QP$B)X6:0
M0XL$`4N+-`$/R$B)\HG`2,'J($J)!$%(B?!(P>XX2,'H*"4`_P``2`GP2(G6
M2,'B"$C!YAB!X@``_P")]D@)\$@)T$J)1$$(28/`"$F#^$!UKDB-L0`"```/
M'X``````2(M!:$@S04!(@\$(2#-!"$@S0?A(C10`2,'H'T@)T(/@_TB)07A(
M.?%UU4R+%TB+7Q!(BW<@2(MO&$R+3PA,B=!,B=)(P>H;2,'@!4@)T`,$)(V4
M,)EY@EI(B=A(BW0D"$@QZ$PAR$@QZ$B-M#69>8):1(TL`DR)RDR)R$C!Z`)(
MP>(>2`G"2(G838GHB=%)P>@;2#'(3"'02#'82`'P3(GN2,'F!4P)QD2-)`9,
MB=9,B=!(P>8>2,'H`D@)\$B+="0038GC2#'"2<'K&T&)P$PAZDB-M#.9>8):
M2#'*2`'R3(GF2,'F!4P)WD2-'!9,B>Y(BU0D&$G![0)(P>8>3`GN2#'P2(V4
M$9EY@EI,B=E,(>!!B?9,,<!(P>D;2`'03(G:2,'B!4@)RDR)X4G![`)$C2P"
M2,'A'DB+5"0@3`GA2(GP2#'(3(GN08G,3"'828V4$)EY@EI(P>X;3#'P2`'0
M3(GJ2,'B!4@)\D2-!`),B=I(BT0D*$G!ZP)(P>(>3`G:3(G&2#'128V$!IEY
M@EI(P>X;3"'I08G33#'A2`'!3(G`2,'@!4@)\$2--`A,B>A(BTPD,$G![0)(
MP>`>3`GH3(GV2#'"28V,#)EY@EI!B<5,(<),,=I(`<I,B?%(P>$%2,'N&T@)
M\4R)QDG!Z`)$C2012,'F'DB+5"0X3`G&2#'P3(GA08GP3"'P28V4$YEY@EI(
MP>D;3#'H2`'03(GB2,'B!4@)RDR)\4G![@)$C1P"2,'A'DB+5"1`3`GQ2(GP
M2#'(3(G>08G.3"'@28V4%9EY@EI(P>X;3#'`2`'03(G:2,'B!4@)\D2-+`),
MB>)(BT0D2$G![`)(P>(>3`GB3(GN2#'128V$`)EY@EI(P>X;3"'908G43#'Q
M2`'!3(GH2,'@!4@)\$2-!`A,B=A(BTPD4$G!ZP)(P>`>3`G83(G&2#'"28V,
M#IEY@EI(P>X;3"'J08G#3#'B2`'*3(G!2,'A!4@)\4R)[DG![0)$C3012,'F
M'DB+5"183`GN2#'P3(GQ08GU3"'`28V4%)EY@EI(P>D;3#'82`'03(GR2,'B
M!4@)RDR)P4G!Z`)$C20"2,'A'DB+5"1@3`G!2(GP2#'(3(GF08G(28V4$YEY
M@EI,(?!(P>X;3#'H2`'03(GB2,'B!4@)\D2-'`),B?)(BT0D:$C!XAY)P>X"
M3`GR3(G>2#'128V$!9EY@EI(P>X;3"'A08G63#'!2`'!3(G82,'@!4@)\$2-
M+`A,B>!(BTPD<$G![`)(P>`>3`G@3(GN2#'"28V,")EY@EI(P>X;3"':08G$
M3#'R2`'*3(GI2,'A!4@)\4R)WDG!ZP)$C0012,'F'DB+5"1X3`G>2#'P3(G!
M08GS3"'H28V4%IEY@EI(P>D;3#'@2`'03(G"2,'B!4@)RDR)Z4G![0)$C30"
M2,'A'DB+E"2`````3`GI2(GP2#'(3(GV08G-3"'`28V4%)EY@EI(P>X;3#'8
M2`'03(GR2,'B!4@)\D2-)`),B<)(BX0DB````$G!Z`)(P>(>3`G"3(GF2#'1
M28V$`YEY@EI(P>X;3"'Q08G03#'I2`'!3(G@2,'@!4@)\$B+M"20````1(T<
M"$R)\$G![@)(P>`>3`GP28VT-9EY@EI-B=U(,<))P>T;B<%,(>),,<)(`?),
MB=Y(P>8%3`GNB?9(`?),B>9)P>P"2,'F'D&)U4P)YDR+I"28````2#'P3"'8
M3XV$()EY@EI(,<A-B>Q)P>P;3`'`38GH2<'@!4T)X$6)P$P!P$V)V$G!ZP))
MP>`>08G$30G828GSB?9-,<-(`[0DJ````$0QVDR+G"2@````2HV,&:'KV6Y-
MB>-)P>L;2`'13(GB2,'B!4P)VHG22`'13(GJ2<'M`DC!XAY!B<M,">I-B<5%
MB<!),=5,`X0DL````$0QZ$V)W4B-M`:AZ]EN3(G82<'M&TC!X`5,">B)P$@!
M\$R)YDG![`)(P>8>08G%3`GF28G4B=)),?1$,>%-B>Q(`Y0DN````$V-A`BA
MZ]EN3(GI2<'L&TC!X05,">&)R4D!R$R)V4G!ZP)(P>$>18G$3`G928GSB?9)
M,<M(`[0DP````$0QV$V)XTB-E`*AZ]EN3(G@2<'K&TC!X`5,"=B)P$@!PDR)
MZ$G![0)(P>`>08G33`GH28G-B<E),<5(`XPDR````$4QZ$V)W4Z-A`:AZ]EN
M3(G>2<'M&TC!Y@5,">Z)]DP!QDV)X$G![`))P>`>08GU30G@28G$B<!-,<1$
M,>)-B>Q(C8P1H>O9;DR)ZDC!X@5)P>P;2`.$)-````!,">*)TD@!T4R)VDG!
MZP)(P>(>08G,3`G:38G#18G`23'33`.$)-@```!$,=Y-B>-(C;0PH>O9;DR)
MX$G!ZQM(P>`%3`G8B<!(`?!,B>Y)P>T"2,'F'D&)PTP)[DF)U8G223'U2`.4
M).````!$,>E-B=U-C80(H>O9;DR)V4G![1M(P>$%3`GIB<E)`<A,B>%)P>P"
M2,'A'D6)Q4P)X4F)](GV23',1#'@38GL2(V4`J'KV6Y,B>A)P>P;2,'@!4P)
MX(G`2`'"3(G82`.T).@```!)P>L"2,'@'D&)U$P)V$F)RXG)23'#2`.,)/``
M``!%,=A-B>-.C80&H>O9;DR)YDG!ZQM(P>8%3`G>B?9,`<9-B>A)P>T"2<'@
M'D&)\TT)Z$F)Q8G`33'%2`.$)/@```!$,>I-B=U(C8P1H>O9;DR)VDG![1M(
MP>(%3`GJB=)(`=%,B>))P>P"2,'B'D&)S4P)XDV)Q$6)P$DQU$0QYDV)[$B-
MM#"AZ]EN3(GH2<'L&TC!X`5,">")P$@!\$R)WDC!YAY)P>L"3`.$)``!``!,
M"=Y)B=-!B<1),?.)TD@#E"0(`0``1#'938GC38V$"*'KV6Y,B>%)P>L;2,'A
M!4P)V8G)20'(3(GI2<'M`DC!X1Y%B<-,">E)B?6)]DDQS4@#M"00`0``1#'H
M38G=2(V4`J'KV6Y,B=A)P>T;2,'@!4P)Z(G`2`'"3(G@2<'L`DC!X!Y!B=5,
M">!)B<R)R4DQQ$4QX$V)[$Z-A`:AZ]EN3(GN2<'L&TC!Y@5,">:)]DP!QDV)
MV$G!ZP))P>`>08GT30G82`.,)!@!``!)B<--,<.)P$@#A"0@`0``1#':38GC
M2<'K&TB-C!&AZ]EN3(GB2,'B!4P)VHG22`'13(GJ2<'M`DC!XAY!B<M,">I-
MB<5%B<!),=5,`X0D*`$``$0Q[DV)W4B-M#"AZ]EN3(G82<'M&TC!X`5,">B)
MP$@!\$R)YDG![`)(P>8>08G%3`GF28G4B=)),?1(`Y0D,`$``$0QX4V)[$V-
MA`BAZ]EN3(GI2<'L&TC!X05,">&)R4D!R$R)V4G!ZP)(P>$>18G$3`G928GS
MB?9),<M$,=A-B>-(`[0D.`$``$B-E`*AZ]EN3(G@2<'K&TC!X`5,"=A$C1P0
M3(GH2<'M`DC!X!Y,">A)B<V)R4DQQ8G"13'H38G=3HV$!J'KV6Y,B=Y)P>T;
M2,'F!4P)[DR+K"1``0``1HTT!DV)X$G![`))P>`>30G@3`G`1(G&28G$2(G0
M2"'P32'<20G$N-R\&X])`<5,`>E-B?5)`<Q,B?%)P>T;2,'A!4P)Z4F)]4$!
MS$R)V4G!ZP)(P>$>3`G908G+20G(32'P32'=30GH3(NL)$@!``!)`<5,`>I-
MB>5)`=!,B>))P>T;2,'B!4P)ZD:-+`),B?))P>X"2,'B'DP)\DV)WD&)T$@)
MT4TAQDPAX4P)\4R+M"10`0``20'&3`'V38GN2`'Q3(GN2<'N&TC!Y@5,"?9$
MC30.3(GF2<'L`DC!YAY,">9-B<2)\4@)\DDAS$PAZDP)XDR+I"18`0``20'$
M30'C38GT3`':38GS2<'C!4G![!M-">-%C20338GK2<'M`DG!XQY-">M)B<U$
MB=I,"=Y)(=5,(?9,">Y,BZPD8`$``$D!Q4T!Z$V)Y4P!QDV)X$G![1M)P>`%
M30GH18TL,$V)\$G![@))P>`>30GP28G61(G&30G#22'V32'C30GS3(NT)&@!
M``!)`<9,`?%-B>Y)`<M,B>E)P>X;2,'A!4P)\4:--!E,B>%)P>P"2,'A'DP)
MX4F)]$&)RTD)R$TAZ$TAW$T)X$R+I"1P`0``20'$3`'B38GT20'03(GR2<'L
M&TC!X@5,">)&C20"3(GJ2<'M`DC!XAY,">I-B=U!B=!("=%-(<5,(?%,">E,
MBZPD>`$``$D!Q4P![DV)Y4@!\4R)YDG![1M(P>8%3`GN1(TL#DR)]DG![@)(
MP>8>3`GV38G&B?%("?))(<Y,(>),"?),B[0D@`$``$D!QDT!\TV)[DP!VDV)
MZTG!XP5)P>X;30GS18TT$TV)XTG![`))P>,>30GC28G,1(G:3`G>22'43"'N
M3`GF3(ND)(@!``!)`<1-`>!-B?1,`<9-B?!)P>P;2<'@!4T)X$6-)#!-B>A)
MP>T"2<'@'DT)Z$F)U42)QDT)PTDA]4TA\TT)ZTR+K"20`0``20'%3`'I38GE
M20'+3(GA2<'M&TC!X05,">E&C2P93(GQ2<'N`DC!X1Y,"?%)B?9)"<A!B<M-
M(=Y-(>!-"?!,B[0DF`$``$D!QDP!\DV)[DD!T$R)ZDG![AM(P>(%3`GR1HTT
M`DR)XDG![`)(P>(>3`GB38G<08G02`G132'$3"'I3`GA3(ND)*`!``!)`<1,
M`>9-B?1(`?%,B?9)P>P;2,'F!4P)YD2-)`Y,B>Y)P>T"2,'F'DP)[DV)Q8GQ
M2`GR22'-3"'R3`GJ3(NL)*@!``!)`<5-`>M-B>5,`=I-B>-)P>T;2<'C!4T)
MZT6-+!--B?-)P>X"2<'C'DT)\TF)SD2)VDP)WDDAUDPAYDP)]DR+M"2P`0``
M20'&30'P38GN3`'&38GH2<'N&TG!X`5-"?!%C30P38G@2<'L`DG!X!Y-">!)
MB=1$B<9-"<-)(?1-(>M-">-,BZ0DN`$``$D!Q$P!X4V)]$D!RTR)\4G![!M(
MP>$%3`GA1HTD&4R)Z4G![0)(P>$>3`GI28GU08G+20G(32'P32'=30GH3(NL
M),`!``!)`<5,`>I-B>5)`=!,B>))P>T;2,'B!4P)ZD:-+`),B?))P>X"2,'B
M'DV)V$P)\D&)UD@)T4TA\$PAX4P)P4R+A"3(`0``20'`3`'&38GH2`'Q3(GN
M2<'H&TC!Y@5,"<9$C00.3(GF2<'L`DC!YAY,B?%,">9!B?1("?),(>%,(>I(
M"<I(BXPDT`$``$@!P4D!RTR)P4@#A"38`0``3`':38G#2,'A!4G!ZQM,"=F)
MR4P!\$@!RDR)Z4G![0)(P>$>08G33`GI38GE08G/2`G.32']3"'&3`GN38G=
M2`'P3(G>2<'M&TC!Y@5,">Z)]D@!\$R)QDG!Z`)(P>8>08G%20GPOM;!8LI,
M,<$QRDB+C"3@`0``2`'Q20',3(GI3`'B38GL2,'A!4G![!M,">&)R4@!RDR)
MV4C!X1Y)P>L"08G420G+3(G!38GF3#'92<'N&T6)P#'(2(N,).@!``!(`?%)
M`<]*C0PX3(G@2,'@!4P)\(G`3(TT`4R)Z$G![0)(P>`>3(G918G;20G%2(N$
M)/`!``!%B?=,,>DQRDR)^4@!\$C!Z1M,`<!(`<),B?A(P>`%2`G(2(N,)/@!
M``")P$@!PDR)X$G![`)(P>`>2`'Q08G03`G@3`'938GK23'#38G$18GM13'>
M2<'L&TZ-'#%,B<%(P>$%3`GAB<E)`<M,B?E)P>\"2,'A'D6)W$D)STB+C"0`
M`@``2`'Q3`'I28G%B<!-,?U$,>I,C2P13(GB3(GA2,'I&TC!X@5("<I,B<%)
MP>@"B=)(P>$>20'52(N4)`@"``!,"<%-B?A%B>Y%B?]),<A(`?)%,<-(`=!,
MB?).C0083(GP2,'J&TC!X`5("=!(B<J)R8G`20'`3(G@2<'L`DC!X!Y%B<-)
M"<1(BX0D$`(``$PQXD$QU4R)VD@!\$P!^$D!Q4R)V$C!X`5(P>H;2`G03(GR
M2<'N`HG`2,'B'DD!Q4B+A"08`@``3`GR18GO2`'P2`'(3(GA18GD2#'103'(
M3(GY20'`3(GX2,'I&TC!X`5("<B)P$D!P$R)V$G!ZP)(P>`>18G&20G#2(N$
M)"`"``!,B?%(P>D;2`'P3`'@28G4B=)-,=Q%,>5.C20H3(GP2,'@!4@)R$B+
MC"0H`@``B<!)`<1,B?A)P>\"2`'Q2,'@'D6)Y4P)^$@!RDR)V4@QP46)VT$Q
MR$R)Z4D!T$R)ZDC!Z1M(P>(%2`G*B=))`=!,B?))P>X"2,'B'D6)QTD)UDB+
ME"0P`@``3(GY2,'I&T@!\DP!VDF)PXG`33'S13'<3HT<(DR)^DC!X@5("<I,
MB>E)P>T"B=)(P>$>20'32(N4)#@"``!,">E%B=Q(`?)(`=!,B?)%B?9(,<I!
M,=!,B>))`<!,B>!(P>H;2,'@!4@)T$B)RHG)B<!)`<!,B?A)P>\"2,'@'D6)
MQ4D)QTB+A"1``@``2`'P3#'Z3`'P03'33(GJ20'#3(GH2,'J&TC!X`5("=!,
MB>))P>P"B<!(P>(>20'#2(N$)$@"``!,">)%B=Y)B=1(`?!(`<A,B?E%B?](
M,=&)TD$QR$J-#`!,B?!-B?!)P>@;2,'@!4P)P(G`2`'!3(GH2<'M`DC!X!Y!
MB<A)"<5(BX0D4`(``$TQ[$4QXTV)Q$@!\$G![!M,`?A)`<-,B<!(P>`%3`G@
MB<!)`<-,B?!(P>`>2<'N`D6)W$P)\$R+M"18`@``20'V20'63(GJ18GM2#'"
M,=%)C10.3(GA38GF2<'N&TC!X05,"?&)R4@!RDR)P4G!Z`)(P>$>08G620G(
M2(N,)&`"``!(`?%,`>E)B<6)P$TQQ44QZTV)]4D!RTR)\4G![1M(P>$%3`GI
MB<E)`<M,B>%)P>P"2,'A'D6)W4D)S$B+C"1H`@``2`'Q2`'(3(G!18G`3#'A
M,<I(C0P03(GH3(GJ2,'J&TC!X`5("=!,B?))P>X"2,'B'HG`20G62(N4)'`"
M``!(`<&)R$@!\DP!PDV)X$TQ\$4QPTF)P$P!VDF)PTG!X`5)P>L;30G828G#
M2,'H`DG!XQY!`=!,B>I)"<-(BX0D>`(``$C!XAY)P>T"00';20G51(GB3(E?
M$$@!\$0![4@!PDR)\$B);QA,,>@QP4B-!`I,B<),B<%(P>(%2,'I&T4!R$@)
MRDR)1P@!T$$!PD0#=R!(BX0DB`(``&1(,P0E*````$R)%TR)=R!U$DB!Q)@"
M``!;74%<05U!7D%?P^A2RO__9I!(@^P(OX````#H4LO__[J)J\WON?[<NIB^
M\.'2PTC'``$C16=(B5`(2(E($$C'0!AV5#(02(EP($C'0"@`````2,=`,```
M``#'0'@`````2(/$",-F9BX/'X0``````)!!5T%62&/"055!5$F)Q5532(GS
M28G\2(/L"$B+=RA(BU<P28UL)#B-#,9(.?%(B4\H2(/2`$C!Z!U(`=!(B4<P
M2&-_>(7_=%A!OT````!(B=Y!*?]%.?U%#T[]2`'O36/W3(GRZ&?*__]!BT0D
M>$0!^(/X0$&)1"1X=!5(@\0(6UU!7$%=05Y!7\-F#Q]$``!,B>=%*?U,`?/H
M\NC__V:008/]/WY508/M0$6)[T'![P9%B?Y)@\8!2<'F!DD!WI#S#V\#3(GG
M2(/#0`\110#S#V]#T`\111#S#V]#X`\112#S#V]#\`\113#HH>C__TPY\W7,
M0<'G!D4I_4ECQ4B#^`AR7$B+$TF)5"0X2(M4`_A(B50%^$B-50A(@^+X2"G5
M2"GK2`'%2(/E^$B#_0AR%TB#Y?@QP$B+#`-(B0P"2(/`"$@YZ'+O18EL)'A(
M@\0(6UU!7$%=05Y!7\,/'T``J`1U'4B%P'3?#[83J`)!B%0D.'33#[=4`_YF
MB50%_NO'BQ-!B50D.(M4`_R)5`7\Z[9F9BX/'X0```````\?`$%6055,C78X
M05152(G]4TR+9BA(B?-,BVXP3(G@2,'H`X/@/XU(`4B8QD0&.(!(8\%,`?"#
M^3@/CYL!``"Z.````#'V*<J#^@@/@F$!``")T4C'``````!(QT0(^`````!(
MC4@(2(/A^$@IR`'"@^+X@_H(<A*#XO@QP(G'@\`(.=!(B30Y<O-,B>A$B&MS
M1(AC=TC!Z!A(B=^(0W!,B>A(P>@0B$-Q3(GH2,'H"(A#<DR)X$C!Z!B(0W1,
MB>!(P>@0B$-U3(G@2,'H"(A#=N@<Y___2(L#2(G?2,'H&(A%`$B+`TC!Z!"(
M10%(BP-(P>@(B$4"2(L#B$4#2(M#"$C!Z!B(101(BT,(2,'H$(A%!4B+0PA(
MP>@(B$4&2(M#"(A%!TB+0Q!(P>@8B$4(2(M#$$C!Z!"(10E(BT,02,'H"(A%
M"DB+0Q"(10M(BT,82,'H&(A%#$B+0QA(P>@0B$4-2(M#&$C!Z`B(10Y(BT,8
MB$4/2(M#($C!Z!B(11!(BT,@2,'H$(A%$4B+0R!(P>@(B$422(M#((A%$UM=
M05Q!74%>Z<C%__\/'X0``````/;"!'5KA=(/A,O^___VP@+&```/A+_^__\Q
MR6:)3!#^Z;/^__\/'P"Z0````"G*=`\QR8G.@\$!.='&!#``<O-(B=_H^.7_
M_V8/[\`/$4,X2<=&,`````!!#Q%&$$$/$48@Z7'^__]F#Q^$``````#'````
M``#'1!#\`````.E5_O__9BX/'X0```````\?`)"0D)"0D)"0D)"0D)"0D)!!
M5T%628G7055!5$R-)4Y5(`!52(TM3E4@`%-!B?U)B?9,*>5(@^P(2,']`^C'
MQ/__2(7M="`QVP\?A```````3(GZ3(GV1(GO0?\4W$B#PP%(.=UUZDB#Q`A;
M74%<05U!7D%?PV9F+@\?A```````D)"0D)"0D)"0D)"0D)"0D//#9BX/'X0`
M``````\?0`"0D)"0D)"0D)"0D)"0D)"02(L-(5D@`.G4Q?__2(/L"$B#Q`C#
M`````0`"`"XN`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E
M<P!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`
M4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!0
M05)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'
M`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0
M`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)0E)!4EE?4$%4
M2`!54T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`"4P,G@`
M)7,E<R5S)7,`<&%R+0!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E
M;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R
M.CI615)324].`#$N,#4R`"UE`"TM`````%]?14Y67U!!4E]#3$5!3E]?("`@
M("`@("`@("`@("`@``````````!P97)L>'-I+F,`````````)7,Z(&-R96%T
M:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A
M9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N
M*0H```````!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````
M````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y
M("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````979A;"`G97AE8R`O=7-R
M+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI
M;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!
M4E]-04=)0RP@)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D
M=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I
M<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER
M92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I
M<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B
M)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M
M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A
M<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I
M('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP
M6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I
M<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL
M96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX
M/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M
M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L
M965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN
M+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@
M/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I
M.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O
M<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N
M86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ
M0D]/5#L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*979A;"!["E]P87)?
M:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@
M)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_
M("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I
M;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^
M("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?
M<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@
M)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*
M;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92!O<B!L87-T.PIM>2`D8G5F
M.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&-H=6YK7W-I>F4@/2`V
M-"`J(#$P,C0["FUY("1M86=I8U]P;W,["FEF("@D<VEZ92`\/2`D8VAU;FM?
M<VEZ92D@>PHD;6%G:6-?<&]S(#T@,#L*?2!E;'-I9B`H*&UY("1M(#T@)'-I
M>F4@)2`D8VAU;FM?<VEZ92D@/B`P*2!["B1M86=I8U]P;W,@/2`D<VEZ92`M
M("1M.PI](&5L<V4@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D8VAU;FM?<VEZ
M93L*?0IW:&EL92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96L@7T9(+"`D;6%G
M:6-?<&]S+"`P.PIR96%D(%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG
M=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!
M4E]-04=)0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD
M;6%G:6-?<&]S("T]("1C:'5N:U]S:7IE.PI]"FQA<W0@:68@)&UA9VEC7W!O
M<R`\(#`["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*<F5A9"!?1D@L
M("1B=68L(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"`M('5N<&%C:R@B
M3B(L("1B=68I+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*;7D@)7)E<75I
M<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@
M97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U
M=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R
M8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@
M.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_
M.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?
M1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT
M*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I
M;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE
M.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?
M87,H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z
M("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN
M86UE?2`]"B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U
M9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@
M7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF
M+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M
M;V1U;&4["FUY("1I;F9O(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L
M97T@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O
M)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/
M.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL
M92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB
M:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K
M*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?
M<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*;W!E
M;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@
M<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O
M='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A
M(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(
M96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER
M92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@
M)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@
M;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@
M+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@
M)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<
M+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]
M"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S
M(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@
M>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H
M+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C
M('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD
M<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T
M7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T
M*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I
M;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@
M('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR
M975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S
M:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*
M;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O
M7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@
M)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G
M32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N
M<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O
M=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET
M92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*
M96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E
M<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG
M="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G
M*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@
M)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0
M)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I
M<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D
M9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]
M"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D
M("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q
M6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@
M)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP
M+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C
M:&EV92`B)'!A<B)=.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M
M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A
M(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE
M=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D
M("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q
M6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E
M860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F
M:6QE72!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["F-L;W-E("1P:#L*
M?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*
M)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,
M62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;
M0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I
M.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)&1A
M=&%?<&]S*2!["G)E860@7T9(+"`D;&]A9&5R+"`D9&%T85]P;W,["GT@96QS
M92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`
M<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0IF;W)E
M86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV
M>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O
M7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N
M(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"([
M"B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G
M("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M
M/G!R:6YT*"1L;V%D97(I.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ
M2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"
M4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE
M("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO
M)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R
M($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,[
M"FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@
M("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R
M96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@
M)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I
M.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@
M/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D
M:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=
M*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@
M(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I
M.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE
M>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@
M86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F
M*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M
M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE
M*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@
M)"\@/2!U;F1E9CL*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE(&]R(&1I
M92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)&9H
M/CL*8VQO<V4@)&9H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD
M8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D52
M0D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ
M1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D
M9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@
M;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV
M93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH
M)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I.PIO=71S*'%Q6U=R
M:71T96X@87,@(B1N86UE(ETI.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD
M;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?
M;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]
M("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE
M=R@Q*3L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1O=70["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4@)&9H.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I
M9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C
M86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN
M="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L
M;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*"1005)?34%'24,I
M.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S
M="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D[
M"G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA
M;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;
M9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3
M:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D
M>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG
M('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#
M:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II
M<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@
M(B1%3E9[4$%27U1%35!](ETI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M
M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R
M+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL
M94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL
M:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG
M.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A
M8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T
M9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D
M9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ
M92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@
M:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92![
M"F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?
M;F%M92)=*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA
M;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B
M.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@
M>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N
M<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R
M;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H
M0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@
M)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN
M+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H
M*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@
M97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E
M<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T
M<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E
M($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U
M:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I
M<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP
M<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG
M97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E
M(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q
M=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*
M979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@
M>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R
M97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L
M('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M
M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)
M4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D*
M*2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N
M9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D
M<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D
M969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I
M;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U
M<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM5
M4T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA
M;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?
M9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S
M=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT
M:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B!M>2`D9F@L("(\
M.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N
M86UE(CH@)"%=.PIS965K("1F:"P@+3$X+"`R.PIM>2`D8G5F.PIR96%D("1F
M:"P@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H
M+"`M-3@L(#(["G)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G
M.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M)&)U9B(["GT*
M96QS92!["FUY("1D:6=E<W0@/2!E=F%L"GL*<F5Q=6ER92!$:6=E<W0Z.E-(
M03L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@)&9H
M+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P
M<F]G;F%M92(Z("0A73L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I
M.PHD8W1X+3YH97AD:6=E<W0["GT@?'P@)&UT:6UE.PHD<W1M<&1I<B`N/2`B
M)$-O;F9I9WM?9&5L:6U]8V%C:&4M)&1I9V5S="(["GT*8VQO<V4H)&9H*3L*
M?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#
M;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T
M;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M
M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N
M=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N
M86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@
M(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G/CIR87<G+"`D=&5M<&YA
M;64@;W(@9&EE('%Q6T-A;B=T('=R:71E("(D=&5M<&YA;64B.B`D(5T["G!R
M:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T
M96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D
M9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L
M;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK
M*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@
M*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%2
M7U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L
M(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II
M9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@
M)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O
M9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?
M97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D
M0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X
M:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0
M?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N
M86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E
M>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD
M,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA
M;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]
M("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD
M969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P
M=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1
M)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E
M;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E
M='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF
M;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!
M344@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!4
M35!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]
M("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'
M3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%
M04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID
M96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[
M4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?
M8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y]
M(#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U
M8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN
M="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS
M=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P
M(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI
M8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R
M87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I
M<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI
M;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P
M97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C
M=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/
M4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD[
M"F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/
M4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<
M9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%
M3D1?7PH```$;`SL$`0``'P```,"%__]0`0``0(G__W@!``!0B?__^`4``)"+
M__\@`0``H(S__Y`!``!PC?__W`$```".__\(`@``4)#__U0"``#0D?__H`(`
M`'"2___$`@``4)/__P@#``"`D___(`,``-"3__\X`P``H)3__V0#``"PE/__
M>`,``,"6___8`P``\);__^P#``#@E___/`0``-"9__]@!```4)K__WP$``"`
MFO__F`0``&";___8!```0*/__Y`%``#0I?__Q`4``%"F__\H!@``8+S__W@&
M``#`O/__D`8``&"^___T!@``KL#__S@'```NP?__@`<``$[!__^8!P``````
M`!0``````````7I2``%X$`$;#`<(D`$'$!0````<````:(K__RL`````````
M`````!0``````````7I2``%X$`$;#`<(D`$``"0````<````:(3__X`#````
M#A!&#AA*#PMW"(``/QH[*C,D(@`````4````1````,"'__\(````````````
M``!(````7`````B+___,`````$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!
M#CB#!T0.0`)L"@XX1`XP00XH0@X@0@X80@X00@X(20L`*````*@```",B___
MA`````!!#A"&`D$.&(,#1PXP`G,*#AA!#A!!#@A!"P!(````U````/"+__],
M`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!TH.8`,F`0H..$$.
M,$$.*$(.($(.&$(.$$(."$0+2````"`!``#TC?__>0$```!"#A"/`D(.&(X#
M0@X@C01"#BB,!4$.,(8&00XX@P='#O`!?@H..$$.,$$.*$(.($(.&$(.$$(.
M"$<+`"````!L`0``*(___Y0`````00X0@P)2#K`!`E,*#A!!#@A)"T````"0
M`0``I(___]X`````0@X0C@)"#AB-`T4.((P$00XHA@5$#C"#!E,.P"`"A`H.
M,$$.*$$.($(.&$(.$$(."$,+%````-0!``!`D/__,`````!$#A!G#@@`%```
M`.P!``!8D/__20````!$#A!]#@@`*`````0"``"0D/__P0````!!#A"&`D$.
M&(,#1P[`0`*G"@X800X000X(1@L0````,`(``#21__\%`````````%P```!$
M`@``,)'__P("````0@X0CP)"#AB.`T(.((T$0@XHC`5$#C"&!D$..(,'40[P
M(0)D"@XX00XP00XH0@X@0@X80@X00@X(1`L"E@[X(4\.@")J#O@A00[P(0``
M`!````"D`@``X)+__RH`````````3````+@"``#\DO__[`````!*#A"&`D$.
M&(,#1`X@=0H.&$C##A!!Q@X(2PMB"@X82,,.$$'&#@A-"P)`#AA!#A!!#@A&
MP\90#B"#`X8"```@````"`,``)R3___C`0```$$.$(,"2PY0`VP!"@X000X(
M1PL8````+`,``&B5__]T`````$0.(&\*#@A%"P``&````$@#``#,E?__)```
M``!$#A!8"@X(1`L``#P```!D`P``X)7__]P`````0@X0C`)!#AB&`T0.((,$
M2PXP`E@..$\.0&X..$$.,&H*#B!!#AA!#A!"#@A!"P"T````I`,``("6___9
M!P```$(.$(\"0@X8C@-"#B"-!$(.*(P%1`XPA@9!#CB#!TX.P(,"`QT"#LB#
M`E8.T(,"90[(@P)"#L"#`@,,`0H..$$.,$$.*$(.($(.&$(.$$(."$4+`WH!
M#LB#`D@.T(,"80[(@P)!#L"#`F(.R(,"20[0@P)!#MB#`D0.X(,"70[`@P(#
M20$.R(,"1`[0@P)H#LB#`D$.P(,"`M<*#LB#`D$.T(,"10L`,````%P$``"H
MG?__C0(```!"#A",`D$.&(8#00X@@P1$#C`#T@$*#B!!#AA!#A!"#@A""S``
M``"0!```!*#__W<`````00X0A@)!#AB#`T<.(`)="@X800X000X(00M$#AA$
M#A!!#@@L````Q`0``%"#__\T`@```$$.$(8"00X8@P-$#E`#M@$*#AA!#A!!
M#@A!"P````!,````]`0``""@__\.%@```$(.$(\"0@X8C@-&#B"-!$(.*(P%
M1`XPA@9!#CB#!T<.T`4#YA4*#CA!#C!!#BA"#B!"#AA"#A!"#@A!"P```!0`
M``!$!0``X+7__U0`````1`X0`D\."&````!<!0``*+;__Y(!````0@X0CP)"
M#AB.`T4.((T$0@XHC`5$#C"&!D$..(,'2@Y``F4*#CA!#C!!#BA"#B!"#AA"
M#A!"#@A'"P+!"@XX00XP00XH0@X@0@X80@X00@X(10M`````P`4``&2W__\S
M`@```$(.$(X"0@X8C0-&#B",!$$.*(8%1`XP@P8#C0$*#BA!#B!"#AA"#A!"
M#@A-"P```````$0````$!@``;KG__V<`````1`X0CP)"#AB.`T4.((T$0@XH
MC`5(#C"&!D@..(,'30Y`<@XX00XP00XH0@X@0@X80@X00@X(`!0```!,!@``
MIKG__P0``````````````!````!D!@``KKG__PX`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````\",```````"P(P``````
M``````````````````````````````````$``````````0,````````!````
M``````P#`````````0`````````<`P```````!T`````````IP0````````,
M``````````@=````````#0````````"\6````````!D`````````<*T@````
M```;``````````@`````````&@````````!XK2```````!P`````````"```
M```````$`````````)@"````````]?[_;P````"P!0````````4`````````
MX`\````````&`````````+`&````````"@````````#<!`````````L`````
M````&``````````5`````````````````````P``````````L"````````(`
M````````*`4````````4``````````<`````````%P````````#@%P``````
M``<``````````!8````````(`````````.`!````````"0`````````8````
M`````/O__V\`````````"`````#^__]O`````(`5````````____;P`````"
M`````````/#__V\`````O!0```````#Y__]O``````<`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"8K2`````````````````````````````V'0```````$8=
M````````5AT```````!F'0```````'8=````````AAT```````"6'0``````
M`*8=````````MAT```````#&'0```````-8=````````YAT```````#V'0``
M``````8>````````%AX````````F'@```````#8>````````1AX```````!6
M'@```````&8>````````=AX```````"&'@```````)8>````````IAX`````
M``"V'@```````,8>````````UAX```````#F'@```````/8>````````!A\`
M```````6'P```````"8?````````-A\```````!&'P```````%8?````````
M9A\```````!V'P```````(8?````````EA\```````"F'P```````+8?````
M````QA\```````#6'P```````.8?````````]A\````````&(````````!8@
M````````)B`````````V(````````$8@````````5B````````!F(```````
M`'8@````````AB````````"6(```````````````````V+$@``````#_____
M`````.!;`````````%@```````"`6````````*!8````````1T-#.B`H4U53
M12!,:6YU>"D@-RXU+C```"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB
M=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS
M='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L
M82YP;'0`+FEN:70`+G!L="YG;W0`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?
M9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N
M9&%T82YR96PN<F\`+F1Y;F%M:6,`+F=O="YP;'0`+F1A=&$`7U]P871C:&%B
M;&5?9G5N8W1I;VY?96YT<FEE<P`N8G-S`"YC;VUM96YT````````````````
M````````````````````````````````````````````````````````````
M````````````````````"P````$````"`````````#@"````````.`(`````
M```<`````````````````````0```````````````````!,````'`````@``
M``````!4`@```````%0"````````)`````````````````````0`````````
M```````````F````!P````(`````````>`(```````!X`@```````"``````
M```````````````$````````````````````.`````4````"`````````)@"
M````````F`(````````4`P````````8`````````"``````````$````````
M`#0```#V__]O`@````````"P!0```````+`%``````````$````````&````
M``````@````````````````````^````"P````(`````````L`8```````"P
M!@```````#`)````````!P````$````(`````````!@`````````1@````,`
M```"`````````.`/````````X`\```````#<!````````````````````0``
M`````````````````$X```#___]O`@````````"\%````````+P4````````
MQ``````````&``````````(``````````@````````!;````_O__;P(`````
M````@!4```````"`%0```````(``````````!P````(````(````````````
M````````:@````0````"```````````6`````````!8```````#@`0``````
M``8`````````"``````````8`````````'0````$````0@````````#@%P``
M`````.`7````````*`4````````&````&0````@`````````&`````````!^
M`````0````8`````````"!T````````('0```````!<`````````````````
M```$````````````````````>0````$````&`````````"`=````````(!T`
M``````"``P``````````````````$``````````0`````````(0````!````
M!@````````"@(````````*`@````````"`````````````````````@`````
M````"`````````"-`````0````8`````````L"````````"P(`````````PX
M```````````````````0````````````````````DP````$````&````````
M`+Q8````````O%@````````)````````````````````!```````````````
M`````)D````!`````@````````#(6````````,A8````````ESX`````````
M``````````@```````````````````"A`````0````(`````````8)<`````
M``!@EP````````0!```````````````````$````````````````````KP``
M``$````"`````````&B8````````:)@```````"H!@``````````````````
M"````````````````````+D````.`````P````````!PK2```````'"M````
M````"`````````````````````@`````````"`````````#%````#P````,`
M````````>*T@``````!XK0````````@````````````````````(````````
M``@`````````T0````$````#`````````("M(```````@*T````````3````
M````````````````$````````````````````-X````&`````P````````"8
MK2```````)BM````````(`(````````'``````````@`````````$```````
M``"(`````0````,`````````N*\@``````"XKP```````$``````````````
M```````(``````````@`````````YP````$````#``````````"P(```````
M`+````````#0`0``````````````````"``````````(`````````/`````!
M`````P````````#0L2```````-"Q````````(`````````````````````@`
M``````````````````#V`````0```(,`````````\+$@``````#PL0``````
M`!@`````````#P`````````(````````````````````$P$```@````#````
M`````""R(```````"+(```````"`$```````````````````(```````````
M`````````!@!```!````,`````````````````````BR````````&```````
M``````````````$``````````0`````````!`````P``````````````````
M```````@L@```````"$!```````````````````!````````````````````
